@@ -9,10 +9,10 @@ __all__ = (
     'IMAGE_DEFAULT_RENDITION_KEY_SET',
     'IMAGE_OPTIMIZE_QUALITY',
     'IMAGE_CREATE_ON_DEMAND',
+    'IMAGE_PLACEHOLDER_PATH',
     'TINYPNG_ALLOWED_EXTENSIONS',
     'TINYPNG_API_KEY_FUNCTION',
     'TINYPNG_API_KEY',
-    'IMAGE_PLACEHOLDER_PATH'
 )
 
 
@@ -51,10 +51,10 @@ IMAGE_CREATE_ON_DEMAND = getattr(
     VERSATILEIMAGEFIELD_CREATE_ON_DEMAND
 )
 
+IMAGE_PLACEHOLDER_PATH = getattr(settings, 'IMAGE_PLACEHOLDER_PATH', None)
+
 TINYPNG_ALLOWED_EXTENSIONS = ['jpeg', 'jpg', 'png']
 
 TINYPNG_API_KEY_FUNCTION = getattr(settings, 'TINYPNG_API_KEY_FUNCTION', None)
 
 TINYPNG_API_KEY = getattr(settings, 'TINYPNG_API_KEY', None)
-
-IMAGE_PLACEHOLDER_PATH = getattr(settings, 'IMAGE_PLACEHOLDER_PATH', None)
